@@ -41,7 +41,6 @@
 #' @importFrom jose jwt_split
 #' @importFrom stats runif
 #' @importFrom xts xts
-#'
 #' @export
 
 placeOrder = function(src = 'tinkoff',
@@ -59,8 +58,6 @@ placeOrder = function(src = 'tinkoff',
                       clientId = '',
                       verbose=TRUE)
 {
-  tryCatch(
-    {
   ## choose broker/exchange
   if(src == 'tinkoff')
   {
@@ -149,16 +146,6 @@ placeOrder = function(src = 'tinkoff',
     }
     }
   }
-    },
-  #if an error occurs, tell me the error
-  error=function(e) {
-    message('Server not response - try later')
-    #print(e)
-  },
-  #if a warning occurs, tell me the warning
-  warning=function(w) {
-    message('Check your internet connection')
-  })
 }
 
 
